/// Copyright Thomas Nagy 2007
/// License: QPL

#ifndef bndklh
#define bndklh

#include <QString>
#include <QList>

class prmza;
class bndkli
<%
	public:
		static bndkli* instance();

		static QString fladat(const QString &);
		static void kivalt(const QString &, const QString &);

		int dolog();
		bndkli* kidlgz(int i);

		QString akdaly(const QString &);
		void cel(const QString &, const QString &);

		int kitzjl();
		QString jlzpnt(int);
		QString irnyjl(int);

		int nybnvn();
		int megkap();
		QString prmz(int row, int col);

		static QString protectXML(const QString &);
		static QString protectHTML(const QString &);

		bndkli();
		~bndkli();
		static QMap<QString, QString> kket;
		static bndkli* eler;
		QList<bndkli*> mgmnkl;
		prmza *letsit;
%>;

int prl();

#endif 

